==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/ProcessSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ProcessSpecFluent<A extends ProcessSpecFluent<A>> extends BaseFluent<A>{
  public ProcessSpecFluent() {
  }
  public ProcessSpecFluent(ProcessSpec instance) {
    instance = (instance != null ? instance : new ProcessSpec());

    if (instance != null) {
      this.withProcess(instance.getProcess());
      this.withSignal(instance.getSignal());
      this.withProcess(instance.getProcess());
      this.withSignal(instance.getSignal());
    }
  }
  private String process;
  private Integer signal;
  public String getProcess() {
    return this.process;
  }
  public A withProcess(String process) {
    this.process=process; return (A) this;
  }
  public boolean hasProcess() {
    return this.process != null;
  }
  public Integer getSignal() {
    return this.signal;
  }
  public A withSignal(Integer signal) {
    this.signal=signal; return (A) this;
  }
  public boolean hasSignal() {
    return this.signal != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProcessSpecFluent that = (ProcessSpecFluent) o;
    if (!java.util.Objects.equals(process, that.process)) return false;

    if (!java.util.Objects.equals(signal, that.signal)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(process,  signal,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (process != null) { sb.append("process:"); sb.append(process + ","); }
    if (signal != null) { sb.append("signal:"); sb.append(signal); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/ProcessSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ProcessSpecFluent<A extends ProcessSpecFluent<A>> extends BaseFluent<A>{
  public ProcessSpecFluent() {
  }
  
  public ProcessSpecFluent(ProcessSpec instance) {
    this.copyInstance(instance);
  }
  private String process;
  private Integer signal;
  
  protected void copyInstance(ProcessSpec instance) {
    instance = (instance != null ? instance : new ProcessSpec());
  
    if (instance != null) {
        this.withProcess(instance.getProcess());
        this.withSignal(instance.getSignal());
        this.withProcess(instance.getProcess());
        this.withSignal(instance.getSignal());
      }
  }
  
  public String getProcess() {
    return this.process;
  }
  
  public A withProcess(String process) {
    this.process=process; return (A) this;
  }
  
  public boolean hasProcess() {
    return this.process != null;
  }
  
  public Integer getSignal() {
    return this.signal;
  }
  
  public A withSignal(Integer signal) {
    this.signal=signal; return (A) this;
  }
  
  public boolean hasSignal() {
    return this.signal != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProcessSpecFluent that = (ProcessSpecFluent) o;
    if (!java.util.Objects.equals(process, that.process)) return false;
  
    if (!java.util.Objects.equals(signal, that.signal)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(process,  signal,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (process != null) { sb.append("process:"); sb.append(process + ","); }
    if (signal != null) { sb.append("signal:"); sb.append(signal); }
    sb.append("}");
    return sb.toString();
  }
  

}
